summaryrefslogtreecommitdiffstats
path: root/wifi/kwireless/linuxwirelesswidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'wifi/kwireless/linuxwirelesswidget.cpp')
-rw-r--r--wifi/kwireless/linuxwirelesswidget.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/wifi/kwireless/linuxwirelesswidget.cpp b/wifi/kwireless/linuxwirelesswidget.cpp
index de35b84b..3efdbf98 100644
--- a/wifi/kwireless/linuxwirelesswidget.cpp
+++ b/wifi/kwireless/linuxwirelesswidget.cpp
@@ -7,8 +7,8 @@
http://www.hackerbuero.org $
*/
-#include <qtooltip.h>
-#include <qtimer.h>
+#include <tqtooltip.h>
+#include <tqtimer.h>
#include <kdebug.h>
#include <klocale.h>
#include <unistd.h> // for ::close
@@ -21,9 +21,9 @@ extern "C" {
}
int LinuxWireLessWidget::socketFD;
-QStringList LinuxWireLessWidget::deviceNames;
+TQStringList LinuxWireLessWidget::deviceNames;
-LinuxWireLessWidget::LinuxWireLessWidget(QWidget *parent, const char* name)
+LinuxWireLessWidget::LinuxWireLessWidget(TQWidget *parent, const char* name)
: KWireLessWidget(parent, name),
m_number (-1)
{
@@ -37,7 +37,7 @@ LinuxWireLessWidget::~LinuxWireLessWidget()
{
kdDebug() << "KWireLessWidget dtor: closing FD, over and out."
<< endl;
- ::close(socketFD); // prevent from using QWidget::close
+ ::close(socketFD); // prevent from using TQWidget::close
socketFD = 0;
}
}
@@ -91,7 +91,7 @@ void LinuxWireLessWidget::poll()
}
// ----- get the device information:
- QStringList::Iterator it;
+ TQStringList::Iterator it;
deviceInfo.clear();
for(it=deviceNames.begin(); it!=deviceNames.end(); ++it)
@@ -110,7 +110,7 @@ void LinuxWireLessWidget::poll()
} else {
// WORK_TO_DO: decide whether updates are needed or not
// create a DeviceInfo object and fill it:
- QString dev, essid, encr;
+ TQString dev, essid, encr;
float quality=0, signal=0, noise=0;
int bitrate;
@@ -192,7 +192,7 @@ void LinuxWireLessWidget::poll()
if(updateToolTip)
{
DeviceInfo *info;
- QString text;
+ TQString text;
for(info=deviceInfo.first(); info; info=deviceInfo.next())
{
@@ -203,7 +203,7 @@ void LinuxWireLessWidget::poll()
.arg(info->qualityString())
.arg(info->bitrateString());
}
- QToolTip::add(this, text);
+ TQToolTip::add(this, text);
updateToolTip = false;
}